==> react-lds-8.7.0.tgz: package/es/components/ExpandableSection/ExpandableSection.js <==
import "core-js/modules/es7.symbol.async-iterator";
import "core-js/modules/es6.object.assign";
import "core-js/modules/es6.symbol";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.object.keys";
import "core-js/modules/es6.object.set-prototype-of";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { Button, ButtonIcon } from '../Button';

var ExpandableSection =
/*#__PURE__*/
function (_Component) {
  _inherits(ExpandableSection, _Component);

  function ExpandableSection(props) {
    var _this;

    _classCallCheck(this, ExpandableSection);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(ExpandableSection).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "toggleSection", function () {
      var _this$props = _this.props,
          open = _this$props.open,
          onToggle = _this$props.onToggle;

      if (open !== null) {
        onToggle();
      } else {
        _this.setState(function (prevState) {
          return {
            isOpen: !prevState.isOpen
          };
        });
      }
    });

    var _this$props2 = _this.props,
        _open = _this$props2.open,
        defaultOpen = _this$props2.defaultOpen;

    if (_open === null) {
      // its uncontrolled
      _this.state = {
        isOpen: defaultOpen
      };
    }

    return _this;
  }

  _createClass(ExpandableSection, [{
    key: "render",
    value: function render() {
      var _this$props3 = this.props,
          children = _this$props3.children,
          className = _this$props3.className,
          defaultOpen = _this$props3.defaultOpen,
          id = _this$props3.id,
          onToggle = _this$props3.onToggle,
          open = _this$props3.open,
          title = _this$props3.title,
          uncollapsable = _this$props3.uncollapsable,
          rest = _objectWithoutProperties(_this$props3, ["children", "className", "defaultOpen", "id", "onToggle", "open", "title", "uncollapsable"]);

      var isOpen = open === null ? this.state.isOpen : null; // eslint-disable-line react/destructuring-assignment

      var sldsClasses = ['slds-section', {
        'slds-is-open': uncollapsable || isOpen || open
      }, className];
      var headerClasses = ['slds-section__title', {
        'slds-theme_shade': uncollapsable
      }];
      return React.createElement("div", _extends({
        className: cx(sldsClasses)
      }, rest), React.createElement("h3", {
        className: cx(headerClasses)
      }, uncollapsable ? React.createElement("span", {
        className: "slds-truncate slds-p-horizontal_small",
        title: title
      }, title) : React.createElement(Button, {
        "aria-controls": id,
        "aria-expanded": isOpen || open,
        className: "slds-section__title-action",
        onClick: this.toggleSection,
        title: title
      }, React.createElement(ButtonIcon, {
        position: "left",
        icon: isOpen || open ? 'chevrondown' : 'chevronright',
        sprite: "utility",
        "aria-hidden": "true"
      }), React.createElement("span", {
        className: "slds-truncate"
      }, title))), React.createElement("div", {
        "aria-hidden": !open,
        className: "slds-section__content",
        id: id
      }, children));
    }
  }]);

  return ExpandableSection;
}(Component);

_defineProperty(ExpandableSection, "defaultProps", {
  className: null,
  open: null,
  uncollapsable: false,
  defaultOpen: false,
  onToggle: function onToggle() {}
});

ExpandableSection.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * children
   */
  children: PropTypes.node.isRequired,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
    * section open, ignored if uncollapsable
    */
  open: PropTypes.bool,

  /**
   * section should start open
   */
  defaultOpen: PropTypes.bool,

  /**
    * uncollapsable
    */
  uncollapsable: PropTypes.bool,

  /**
    * id linking button and expandable content
    */
  id: PropTypes.string.isRequired,

  /**
    * section title
    */
  title: PropTypes.string.isRequired,

  /**
   * function if component is controlled
   */
  onToggle: PropTypes.func
} : {};
export default ExpandableSection;

==> react-lds-9.1.0.tgz: package/es/components/ExpandableSection/ExpandableSection.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.symbol.description";
import "core-js/modules/es.symbol.iterator";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.array.iterator";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.get-prototype-of";
import "core-js/modules/es.object.keys";
import "core-js/modules/es.object.set-prototype-of";
import "core-js/modules/es.object.to-string";
import "core-js/modules/es.string.iterator";
import "core-js/modules/web.dom-collections.iterator";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { Button, ButtonIcon } from '../Button';

var ExpandableSection =
/*#__PURE__*/
function (_Component) {
  _inherits(ExpandableSection, _Component);

  function ExpandableSection(props) {
    var _this;

    _classCallCheck(this, ExpandableSection);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(ExpandableSection).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "toggleSection", function () {
      var _this$props = _this.props,
          open = _this$props.open,
          onToggle = _this$props.onToggle;

      if (open !== null) {
        onToggle();
      } else {
        _this.setState(function (prevState) {
          return {
            isOpen: !prevState.isOpen
          };
        });
      }
    });

    var _this$props2 = _this.props,
        _open = _this$props2.open,
        defaultOpen = _this$props2.defaultOpen;

    if (_open === null) {
      // its uncontrolled
      _this.state = {
        isOpen: defaultOpen
      };
    }

    return _this;
  }

  _createClass(ExpandableSection, [{
    key: "render",
    value: function render() {
      var _this$props3 = this.props,
          children = _this$props3.children,
          className = _this$props3.className,
          defaultOpen = _this$props3.defaultOpen,
          id = _this$props3.id,
          onToggle = _this$props3.onToggle,
          open = _this$props3.open,
          title = _this$props3.title,
          uncollapsable = _this$props3.uncollapsable,
          rest = _objectWithoutProperties(_this$props3, ["children", "className", "defaultOpen", "id", "onToggle", "open", "title", "uncollapsable"]);

      var isOpen = open === null ? this.state.isOpen : null; // eslint-disable-line react/destructuring-assignment

      var sldsClasses = ['slds-section', {
        'slds-is-open': uncollapsable || isOpen || open
      }, className];
      var headerClasses = ['slds-section__title', {
        'slds-theme_shade': uncollapsable
      }];
      return React.createElement("div", _extends({
        className: cx(sldsClasses)
      }, rest), React.createElement("h3", {
        className: cx(headerClasses)
      }, uncollapsable ? React.createElement("span", {
        className: "slds-truncate slds-p-horizontal_small",
        title: title
      }, title) : React.createElement(Button, {
        "aria-controls": id,
        "aria-expanded": isOpen || open,
        className: "slds-section__title-action",
        onClick: this.toggleSection,
        title: title
      }, React.createElement(ButtonIcon, {
        position: "left",
        icon: isOpen || open ? 'chevrondown' : 'chevronright',
        sprite: "utility",
        "aria-hidden": "true"
      }), React.createElement("span", {
        className: "slds-truncate"
      }, title))), React.createElement("div", {
        "aria-hidden": !open,
        className: "slds-section__content",
        id: id
      }, children));
    }
  }]);

  return ExpandableSection;
}(Component);

_defineProperty(ExpandableSection, "defaultProps", {
  className: null,
  open: null,
  uncollapsable: false,
  defaultOpen: false,
  onToggle: function onToggle() {}
});

ExpandableSection.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * children
   */
  children: PropTypes.node.isRequired,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
    * section open, ignored if uncollapsable
    */
  open: PropTypes.bool,

  /**
   * section should start open
   */
  defaultOpen: PropTypes.bool,

  /**
    * uncollapsable
    */
  uncollapsable: PropTypes.bool,

  /**
    * id linking button and expandable content
    */
  id: PropTypes.string.isRequired,

  /**
    * section title
    */
  title: PropTypes.string.isRequired,

  /**
   * function if component is controlled
   */
  onToggle: PropTypes.func
} : {};
export default ExpandableSection;
